nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Mainclksafety

Struct Mainclksafety 

#[repr(transparent)]
pub struct Mainclksafety(pub u32);
Main Clock Safety

Tuple Fields

0: u32

Implementations

Source

impl Mainclksafety

pub const fn delay(&self) -> u16

Main Clock turn on delay for Deep Sleep wake up

pub const fn set_delay(&mut self, val: u16)

Main Clock turn on delay for Deep Sleep wake up