#[repr(transparent)]pub struct SystemStickCalib(pub u32);Expand description
system stick calibration
Tuple Fields
0: u32Implementations
Sourceimpl SystemStickCalib
impl SystemStickCalib
Sourcepub const fn system_stick_calib(&self) -> u32
pub const fn system_stick_calib(&self) -> u32
Selects the system secure tick calibration value of the M33.
Sourcepub const fn set_system_stick_calib(&mut self, val: u32)
pub const fn set_system_stick_calib(&mut self, val: u32)
Selects the system secure tick calibration value of the M33.