nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Usbphypll0locktimediv2

Struct Usbphypll0locktimediv2 

#[repr(transparent)]
pub struct Usbphypll0locktimediv2(pub u32);
USB PHY PLL0 lock time division 2

Tuple Fields

0: u32

Implementations

Source

impl Usbphypll0locktimediv2

pub const fn locktimediv2(&self) -> u16

USBPHYPLL0 Lock Time: Programmed lock time is in uS (micro-seconds) and is programmed as half the actual lock time value

pub const fn set_locktimediv2(&mut self, val: u16)

USBPHYPLL0 Lock Time: Programmed lock time is in uS (micro-seconds) and is programmed as half the actual lock time value