#[repr(transparent)]pub struct HwunlockDisable(pub u32);Expand description
HW unlock disable
Tuple Fields
0: u32Implementations
Sourceimpl HwunlockDisable
impl HwunlockDisable
Sourcepub const fn hwunlock_disable(&self) -> u8
pub const fn hwunlock_disable(&self) -> u8
HW Unlock / Disable: Disable the OTP unlock for test, Teal and DSP debug Write any value to disable the allow testmode signal/allow CPU0 debug signal/allow CPU1 debug signal
Sourcepub const fn set_hwunlock_disable(&mut self, val: u8)
pub const fn set_hwunlock_disable(&mut self, val: u8)
HW Unlock / Disable: Disable the OTP unlock for test, Teal and DSP debug Write any value to disable the allow testmode signal/allow CPU0 debug signal/allow CPU1 debug signal