#[repr(transparent)]pub struct Hwwake(pub u32);Expand description
Hardware Wake-up control
Tuple Fields
0: u32Implementations
Sourceimpl Hwwake
impl Hwwake
Sourcepub const fn forcewake(&self) -> bool
pub const fn forcewake(&self) -> bool
Force peripheral clocking to stay on during deep-sleep mode. When 1, clocking to peripherals is prevented from being shut down when the CPU enters deep-sleep mode. This is intended to allow a coprocessor to continue operating while the main CPU(s) are shut down.
Sourcepub const fn set_forcewake(&mut self, val: bool)
pub const fn set_forcewake(&mut self, val: bool)
Force peripheral clocking to stay on during deep-sleep mode. When 1, clocking to peripherals is prevented from being shut down when the CPU enters deep-sleep mode. This is intended to allow a coprocessor to continue operating while the main CPU(s) are shut down.
Sourcepub const fn fcwake(&self) -> bool
pub const fn fcwake(&self) -> bool
Wake for Flexcomm Interfaces. When 1, any Flexcomm Interface FIFO reaching the level specified by its own TXLVL will cause peripheral clocking to wake up temporarily while the related status is asserted.
Sourcepub const fn set_fcwake(&mut self, val: bool)
pub const fn set_fcwake(&mut self, val: bool)
Wake for Flexcomm Interfaces. When 1, any Flexcomm Interface FIFO reaching the level specified by its own TXLVL will cause peripheral clocking to wake up temporarily while the related status is asserted.
Sourcepub const fn dmicwake(&self) -> bool
pub const fn dmicwake(&self) -> bool
Wake for Digital Microphone. When 1, the digital microphone input FIFO reaching the level specified by TRIGLVL of either channel will cause peripheral clocking to wake up temporarily while the related status is asserted.
Sourcepub const fn set_dmicwake(&mut self, val: bool)
pub const fn set_dmicwake(&mut self, val: bool)
Wake for Digital Microphone. When 1, the digital microphone input FIFO reaching the level specified by TRIGLVL of either channel will cause peripheral clocking to wake up temporarily while the related status is asserted.
Sourcepub const fn dmac0wake(&self) -> bool
pub const fn dmac0wake(&self) -> bool
Wake for DMAC0. When 1, DMAC0 being busy will cause peripheral clocking to remain running until DMAC0 completes. This is generally used in conjunction with bit 1 and/or 2 in order to prevent peripheral clocking from being shut down as soon as the cause of wake-up is cleared, but before DMAC0 has completed its related activity.
Sourcepub const fn set_dmac0wake(&mut self, val: bool)
pub const fn set_dmac0wake(&mut self, val: bool)
Wake for DMAC0. When 1, DMAC0 being busy will cause peripheral clocking to remain running until DMAC0 completes. This is generally used in conjunction with bit 1 and/or 2 in order to prevent peripheral clocking from being shut down as soon as the cause of wake-up is cleared, but before DMAC0 has completed its related activity.
Sourcepub const fn dmac1wake(&self) -> bool
pub const fn dmac1wake(&self) -> bool
Wake for DMAC1. When 1, DMAC1 being busy will cause peripheral clocking to remain running until DMAC1 completes. This is generally used in conjunction with bit 1 and/or 2 in order to prevent peripheral clocking from being shut down as soon as the cause of wake-up is cleared, but before DMAC1 has completed its related activity.
Sourcepub const fn set_dmac1wake(&mut self, val: bool)
pub const fn set_dmac1wake(&mut self, val: bool)
Wake for DMAC1. When 1, DMAC1 being busy will cause peripheral clocking to remain running until DMAC1 completes. This is generally used in conjunction with bit 1 and/or 2 in order to prevent peripheral clocking from being shut down as soon as the cause of wake-up is cleared, but before DMAC1 has completed its related activity.
Sourcepub const fn espiwake(&self) -> bool
pub const fn espiwake(&self) -> bool
Wake for ESPI. When 1, ESPI being busy will cause peripheral clocking to remain running until ESPI completes. This is generally used in conjunction with bit 1 and/or 2 in order to prevent peripheral clocking from being shut down as soon as the cause of wake-up is cleared, but before ESPI has completed its related activity.
Sourcepub const fn set_espiwake(&mut self, val: bool)
pub const fn set_espiwake(&mut self, val: bool)
Wake for ESPI. When 1, ESPI being busy will cause peripheral clocking to remain running until ESPI completes. This is generally used in conjunction with bit 1 and/or 2 in order to prevent peripheral clocking from being shut down as soon as the cause of wake-up is cleared, but before ESPI has completed its related activity.